==> gs2-cdk-1.0.86.tar.gz: gs2-cdk-1.0.86/src/gs2_cdk/guild/model/__init__.py <==
# Copyright 2016- Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from .Namespace import Namespace
from .options.NamespaceOptions import NamespaceOptions
from .GuildModel import GuildModel
from .options.GuildModelOptions import GuildModelOptions
from .Inbox import Inbox
from .options.InboxOptions import InboxOptions
from .Guild import Guild
from .options.GuildOptions import GuildOptions
from .enum.GuildJoinPolicy import GuildJoinPolicy
from .LastGuildMasterActivity import LastGuildMasterActivity
from .options.LastGuildMasterActivityOptions import LastGuildMasterActivityOptions
from .RoleModel import RoleModel
from .options.RoleModelOptions import RoleModelOptions
from .Member import Member
from .options.MemberOptions import MemberOptions
from .ReceiveMemberRequest import ReceiveMemberRequest
from .options.ReceiveMemberRequestOptions import ReceiveMemberRequestOptions
from .IgnoreUser import IgnoreUser
from .options.IgnoreUserOptions import IgnoreUserOptions
from .VerifyActionResult import VerifyActionResult
from .options.VerifyActionResultOptions import VerifyActionResultOptions
from .ConsumeActionResult import ConsumeActionResult
from .options.ConsumeActionResultOptions import ConsumeActionResultOptions
from .AcquireActionResult import AcquireActionResult
from .options.AcquireActionResultOptions import AcquireActionResultOptions
from .TransactionResult import TransactionResult
from .options.TransactionResultOptions import TransactionResultOptions
from .CurrentMasterData import CurrentMasterData

==> gs2-cdk-1.0.94.tar.gz: gs2-cdk-1.0.94/src/gs2_cdk/guild/model/__init__.py <==
# Copyright 2016- Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from .Namespace import Namespace
from .options.NamespaceOptions import NamespaceOptions
from .GuildModel import GuildModel
from .options.GuildModelOptions import GuildModelOptions
from .Inbox import Inbox
from .options.InboxOptions import InboxOptions
from .Guild import Guild
from .options.GuildOptions import GuildOptions
from .enums.GuildJoinPolicy import GuildJoinPolicy
from .LastGuildMasterActivity import LastGuildMasterActivity
from .options.LastGuildMasterActivityOptions import LastGuildMasterActivityOptions
from .RoleModel import RoleModel
from .options.RoleModelOptions import RoleModelOptions
from .Member import Member
from .options.MemberOptions import MemberOptions
from .ReceiveMemberRequest import ReceiveMemberRequest
from .options.ReceiveMemberRequestOptions import ReceiveMemberRequestOptions
from .IgnoreUser import IgnoreUser
from .options.IgnoreUserOptions import IgnoreUserOptions
from .VerifyActionResult import VerifyActionResult
from .options.VerifyActionResultOptions import VerifyActionResultOptions
from .ConsumeActionResult import ConsumeActionResult
from .options.ConsumeActionResultOptions import ConsumeActionResultOptions
from .AcquireActionResult import AcquireActionResult
from .options.AcquireActionResultOptions import AcquireActionResultOptions
from .TransactionResult import TransactionResult
from .options.TransactionResultOptions import TransactionResultOptions
from .CurrentMasterData import CurrentMasterData
